/*
 * Created on Dec 2, 2004
 *
 * TextFile class represents a text file in memory instead of on a
 * hard drive, usb key, or CD ROM.
 */
package cs1020;

/**
 * @author t a y l o r@msoe.edu
 *
 * TextFile class represents a text file in memory instead of on a
 * hard drive, usb key, or CD ROM.
 */
public class TextFile {
    /**
     * Represents the filename
     */
    private String filename;
    /**
     * Represents the contents of the file
     */
    private String contents;
    
    /**
     * Default Constructor declared private so that nobody makes a
     * TextFile without a filename.
     * 
     * @author t a y l o r@msoe.edu
     */
    private TextFile() {
    }
    
    /**
     * Constructor - Creates a TextFile object with a filename and
     * blank contents.
     * 
     * @author t a y l o r@msoe.edu
     * 
     * @param name Filename for the TextFile.
     */
    public TextFile(String name) {
        filename = name;
        contents = "";
    }
    
    /**
     * Constructor - Creates a TextFile object with a filename and
     * contents.
     * 
     * @author t a y l o r@msoe.edu
     * 
     * @param name Filename for the TextFile.
     * @param contents Contents of the TextFile.
     */
    public TextFile(String name, String contents) {
        filename = name;
        this.contents = contents;
    }
    
    /**
     * Replaces the contents of the TextFile.
     * 
     * @author t a y l o r@msoe.edu
     * 
     * @param contents Contents of the TextFile.
     */
    public void setContents(String contents) {
        this.contents = contents;
    }

    /**
     * Gets the contents of the TextFile.
     * 
     * @author t a y l o r@msoe.edu
     * 
     * @return Contents of the TextFile.
     */
    public String getContents() {
        return contents;
    }
    /**
     * Replaces the contents of the TextFile.
     * 
     * @author t a y l o r@msoe.edu
     * 
     * @param contents Contents of the TextFile.
     */
    public void setFilename(String name) {
        filename = name;
    }

    /**
     * Gets the contents of the TextFile.
     * 
     * @author t a y l o r@msoe.edu
     * 
     * @return Contents of the TextFile.
     */
    public String getFilename() {
        return filename;
    }
    
    /**
     * Gets the size of the TextFile.  This is the sum of the number
     * of characters in the filename and contents.
     * 
     * @author t a y l o r@msoe.edu
     * 
     * @return Size of the TextFile.
     */
    public int size() {
        return filename.length() + contents.length();
    }
    
    /**
     * Adds to the contents of the TextFile.
     * 
     * @author t a y l o r@msoe.edu
     * 
     * @param text Additional text for the TextFile.
     */
    public void concat(String text) {
        this.contents += text;
    }

    /**
     * Removes the contents of the TextFile.
     * 
     * @author t a y l o r@msoe.edu
     */
    public void erase() {
        this.contents = "";
    }
    
    /**
     * Does what you would think.
     * 
     * @author t a y l o r@msoe.edu
     * 
     * @param obj TextFile to be compared against.
     * 
     * @return True if and only if the two TextFiles have the
     * same value for their contents and filename.
     */
    public boolean equals(TextFile obj) {
        return (filename.equals(obj.filename)) && (contents.equals(obj.contents));
    }
}
